@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2021, Adrian Dusa
+# Copyright (c) 2019 - 2022, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -24,7 +24,7 @@
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 `checkMV` <- function(
-    expression, snames = "", noflevels = NULL, data = NULL, categories = list(), ...
+    expression, snames = "", noflevels = NULL, data = NULL, categorical = FALSE, categories = list(), ...
 ) {
     curly <- any(grepl("[{]", expression))
     if (length(unlist(gregexpr(ifelse(curly, "[{]+", "\\[+"), expression))) != length(unlist(gregexpr(ifelse(curly, "[}]+", "\\]+"), expression)))) {
@@ -42,7 +42,14 @@
         tempexpr <- squareBrackets(tempexpr, outside = TRUE)
     }
     if (length(insb) != length(tempexpr)) {
-        stopError("Incorrect expression, some set names do not have brackets.")
+        error <- TRUE
+        if (categorical) {
+            tempexpr2 <- tempexpr[!is.element(tempexpr, names(unlist(unname(categories))))]
+            error <- length(insb) != length(tempexpr2)
+        }
+        if (error) {
+            stopError("Incorrect expression, some set names do not have brackets.")
+        }
     }
     if (any(grepl("[a-zA-Z]", gsub("[,|;]", "", insb)))) {
         stopError("Invalid [multi]values, levels should be numeric.")
